==> humhub-1.11.0-beta.2.tar.gz: humhub-1.11.0-beta.2/protected/humhub/modules/content/messages/es/base.php <==
<?php

return [
    '(Also visible to non-members of this space)' => '(También visible a quienes no son miembros de este espacio)',
    '<strong>Confirm</strong> post deletion' => '<strong>Confirma</strong> el borrado de la entrada',
    '<strong>Move</strong> content' => '<strong>Mover</strong> contenido',
    '<strong>Permalink</strong> to this post' => '<strong>Permalink</strong> a esta entrada',
    'Add a member to notify' => 'Añadir un miembro a notificar',
    'Add tag...' => 'Añadir etiqueta...',
    'Archived' => 'Archivado',
    'Attach Files' => 'Adjuntar archivos',
    'Back to stream' => 'Volver a Actividad',
    'Cancel' => 'Cancelar',
    'Cancel Edit' => 'Cancelar edición',
    'Change to "Private"' => 'Hacer Privado',
    'Change to "Public"' => 'Hacer Público',
    'Comments are locked' => 'Los comentarios están cerrados',
    'Comments are unlocked' => 'Los comentarios están abiertos',
    'Content' => 'Contenido',
    'Content Tag with invalid contentcontainer_id assigned.' => 'Se ha asignado una etiqueta de contenido no válida a contentcontainer_id.',
    'Content has been moved to {spacename}' => 'El contenido ha sido movido a {spacename}',
    'Content visibility' => 'Visibilidad del contenido',
    'Could not delete content!' => '¡No se pudo borrar el contenido!',
    'Could not find requested content!' => '¡No se pudo encontrar el contenido solicitado!',
    'Created at:' => 'Creado en:',
    'Created by me' => 'Creado por mi',
    'Creation time' => 'Fecha de creación',
    'Delete' => 'Borrar',
    'Do you really want to delete this post? All likes and comments will be lost!' => '¿Realmente deseas borrar esta entrada? ¡Todos los "Me gusta" y los comentarios se perderán!',
    'Edit' => 'Editar',
    'Filter' => 'Filtro',
    'I\'m involved' => 'En aquello que me concierna',
    'Invalid content id given!' => '¡Se ha introducido un id de contenido no válido!',
    'Invalid request method!' => '¡Método de solicitud no válido!',
    'Invalid space selection.' => 'Selección de espacio inválida.',
    'Last update' => 'Última actualización',
    'Last updated {time}' => 'Última actualización {time}',
    'Load more' => 'Cargar Más',
    'Lock comments' => 'Cerrar los comentarios',
    'Maximum number of pinned items reached!<br>You can only pin up to {count} items at once.' => 'Has alcanzado el número máximo de items anclados!<br />Sólo puedes anclar {count} items al mismo tiempo.',
    'Move content' => 'Mover contenido',
    'Move to archive' => 'Mover a archivo',
    'No matches with your selected filters!' => '¡No se han encontrado resultados con los filtros seleccionados!',
    'No tags found for the given query' => 'No se han encontrado etiquetas para esta búsqueda',
    'None' => 'Ninguno',
    'Nothing here yet!' => '¡No hay nada aquí todavía!',
    'Notify members' => 'Notificar Miembros',
    'Permalink' => 'Permalink',
    'Pin to top' => 'Fijar en la parte superior',
    'Pinned' => 'Fijado',
    'Private' => 'Privado',
    'Public' => 'Público',
    'Select type...' => 'Seleccione tipo...',
    'Specify who can see this content.' => 'Especifica quién puede ver este contenido.',
    'Submit' => 'Publicar',
    'Tag' => 'Etiqueta',
    'Target Space' => 'Espacio de destino',
    'The author of this content is not allowed to create private content within the selected space.' => 'El autor de este contenido no está autorizado a crear contenido privado dentro del espacio seleccionado.',
    'The author of this content is not allowed to create public content within the selected space.' => 'El autor de este contenido no está autorizado a crear contenido públilco dentro del espacio seleccionado.',
    'The author of this content is not allowed to create this type of content within this space.' => 'Al autor de este contenido no le es permitido crear este tipo de contenido dentro de este espacio.',
    'The content can\'t be moved to its current space.' => 'No se puede mover el contenido a su espacio actual.',
    'The content has been archived.' => 'Este contenido ha sido activado.',
    'The content has been deleted.' => 'Este contenido ha sido borrado.',
    'The content has been unarchived.' => 'Este contenido ha sido desarchivado.',
    'The given name is already in use.' => 'El nombre está ya en uso.',
    'The module {moduleName} is not enabled on the selected target space.' => 'El módulo {moduleName} no está habilitado en el espacio de destino que ha seleccionado.',
    'This action is disabled!' => '¡Esta acción no está permitida!',
    'This content type can\'t be moved due to a missing module-id setting.' => 'Este tipo de contenido no se puede mover debido a una configuración de módulo que no existe.',
    'This content type can\'t be moved.' => 'No se puede mover este contenido.',
    'This space is archived.' => 'Este espacio ha sido archivado.',
    'This space is not visible!' => '¡Este espacio no es visible!',
    'Topics' => 'Temas',
    'Turn off notifications' => 'Desactivar notificaciones',
    'Turn on notifications' => 'Activar Notificaciones',
    'Unarchive' => 'Desarchivar',
    'Unlock comments' => 'Abrir los comentarios',
    'Unpin' => 'Desfijar',
    'Updated' => 'Actualizado',
    'Visible also to unregistered users' => 'También visible a usuarios no registrados',
    'Visible only to you' => 'Visible sólo para ti',
    'Visible to all Space members' => 'Visible para todos los miembros del Espacio',
    'Visible to all signed in users' => 'Visible para todos los usuarios autenticados',
    'Visible to friends of {displayName}' => 'Visible para amigos de {displayName}',
    'Visible to you and {displayName}' => 'Visible para ti y {displayName}',
    'Visible to your friends' => 'Visible para tus amigos',
    'With attachments' => 'Con archivos vinculados',
    'You cannot block the space owner!' => '¡No puedes bloquear al propietario del espacio!',
    'You cannot block the user of the same container!' => '¡No puedes bloquear al usuario del mismo contenedor!',
    'You cannot block yourself!' => '¡No puedes bloquearte a ti mismo!',
    'You do not have the permission to move this content to the given space.' => 'No tienes autorización para mover este contenido a ese espacio.',
    'You do not have the permission to move this content.' => 'No tienes autorización para mover ese contenido.',
    'Your last edit state has been saved!' => 'Este contenido ha sido grabado.',
    'in' => 'en',
    '<strong>Delete</strong> content?' => '',
    'Confirm' => '',
    'New Updates Available!' => '',
];

==> humhub-1.16.0-beta.2.tar.gz: humhub-1.16.0-beta.2/protected/humhub/modules/content/messages/es/base.php <==
<?php

return [
    '(Also visible to non-members of this space)' => '(También visible a quienes no son miembros de este espacio)',
    '<strong>Delete</strong> content?' => '¿<strong>Borrar</strong> el contenido?',
    '<strong>Move</strong> content' => '<strong>Mover</strong> contenido',
    '<strong>Permalink</strong> to this post' => '<strong>Permalink</strong> a esta entrada',
    '<strong>Scheduling</strong> Options' => 'Opciones de <strong>programación</strong>',
    'Activate scheduling' => 'Activar la programación',
    'Add a member to notify' => 'Añadir un miembro a notificar',
    'Add tag...' => 'Añadir etiqueta...',
    'Archived' => 'Archivado',
    'Attach Files' => 'Adjuntar archivos',
    'Back to stream' => 'Volver a Actividad',
    'Cancel' => 'Cancelar',
    'Cancel Edit' => 'Cancelar edición',
    'Cannot notify the author.' => 'No se puede notificar al autor.',
    'Change to "Private"' => 'Hacer Privado',
    'Change to "Public"' => 'Hacer Público',
    'Comments are locked' => 'Los comentarios están cerrados',
    'Comments are unlocked' => 'Los comentarios están abiertos',
    'Configure' => 'Configurar',
    'Confirm' => 'Confirmar',
    'Content' => 'Contenido',
    'Content Tag with invalid contentcontainer_id assigned.' => 'Se ha asignado una etiqueta de contenido no válida a contentcontainer_id.',
    'Content has been moved to {spacename}' => 'El contenido ha sido movido a {spacename}',
    'Could not find requested content!' => '¡No se pudo encontrar el contenido solicitado!',
    'Create as draft' => 'Crear como borrador',
    'Created at:' => 'Creado en:',
    'Created by me' => 'Creado por mi',
    'Creation time' => 'Fecha de creación',
    'Delete' => 'Borrar',
    'Deleted' => 'Borrar',
    'Do you want to delete this content, including all comments and attachments?<br><br>Please note: If a stream entry was created using a module, the original content that this entry is linked to will also be deleted.' => '¿Quiere eliminar este contenido, incluidos todos los comentarios y archivos vinculados?<br><br>Por favor tenga en cuenta que si una publicación se ha creado mediante un módulo el contenido original al que enlaza esta entrada será borrado también.',
    'Draft' => 'Borrador',
    'Edit' => 'Editar',
    'Enable' => 'Activar',
    'Enabled' => 'Activado',
    'Filter' => 'Filtro',
    'Hidden' => 'Oculto',
    'I\'m involved' => 'En aquello que me concierna',
    'Invalid content id given!' => '¡Se ha introducido un id de contenido no válido!',
    'Invalid request method!' => '¡Método de solicitud no válido!',
    'Invalid space selection.' => 'Selección de espacio inválida.',
    'Last update' => 'Última actualización',
    'Last updated {time}' => 'Última actualización {time}',
    'Load more' => 'Cargar Más',
    'Lock comments' => 'Cerrar los comentarios',
    'Maximum number of pinned items reached!<br>You can only pin up to {count} items at once.' => 'Has alcanzado el número máximo de items anclados!<br />Sólo puedes anclar {count} items al mismo tiempo.',
    'Move content' => 'Mover contenido',
    'Move to archive' => 'Mover a archivo',
    'New Updates Available!' => 'Hay actualizaciones disponibles.',
    'No matches with your selected filters!' => '¡No se han encontrado resultados con los filtros seleccionados!',
    'No tags found for the given query' => 'No se han encontrado etiquetas para esta búsqueda',
    'None' => 'Ninguno',
    'Note: Due to technical reasons there may be a delay of a few minutes.' => 'Nota: Por razones técnicas puede producirse un retraso de unos minutos',
    'Nothing here yet!' => '¡No hay nada aquí todavía!',
    'Notify members' => 'Notificar Miembros',
    'Permalink' => 'Permalink',
    'Pin to top' => 'Fijar en la parte superior',
    'Pinned' => 'Fijado',
    'Private' => 'Privado',
    'Public' => 'Público',
    'Publish draft' => 'Publicar borrador',
    'Save as draft' => 'Guardar como borrador',
    'Save scheduling' => 'Guardar programación',
    'Schedule publication' => 'Programar publicación',
    'Scheduled for {dateTime}' => 'Programado para {dateTime}',
    'Select type...' => 'Seleccione tipo...',
    'Specify who can see this content.' => 'Especifica quién puede ver este contenido.',
    'Submit' => 'Publicar',
    'Tag' => 'Etiqueta',
    'Target Space' => 'Espacio de destino',
    'The author of this content is not allowed to create private content within the selected space.' => 'El autor de este contenido no está autorizado a crear contenido privado dentro del espacio seleccionado.',
    'The author of this content is not allowed to create public content within the selected space.' => 'El autor de este contenido no está autorizado a crear contenido públilco dentro del espacio seleccionado.',
    'The author of this content is not allowed to create this type of content within this space.' => 'Al autor de este contenido no le es permitido crear este tipo de contenido dentro de este espacio.',
    'The content can\'t be moved to its current space.' => 'No se puede mover el contenido a su espacio actual.',
    'The content cannot be published!' => '¡El contenido no puede ser publicado!',
    'The content has been archived.' => 'Este contenido ha sido activado.',
    'The content has been deleted.' => 'Este contenido ha sido borrado.',
    'The content has been successfully published.' => 'El contenido se ha publicado correctamente.',
    'The content has been unarchived.' => 'Este contenido ha sido desarchivado.',
    'The given name is already in use.' => 'El nombre está ya en uso.',
    'The module {moduleName} is not enabled on the selected target space.' => 'El módulo {moduleName} no está habilitado en el espacio de destino que ha seleccionado.',
    'This action is disabled!' => '¡Esta acción no está permitida!',
    'This content type can\'t be moved due to a missing module-id setting.' => 'Este tipo de contenido no se puede mover debido a una configuración de módulo que no existe.',
    'This content type can\'t be moved.' => 'No se puede mover este contenido.',
    'This space is archived.' => 'Este espacio ha sido archivado.',
    'This space is not visible!' => '¡Este espacio no es visible!',
    'Topics' => 'Temas',
    'Turn off notifications' => 'Desactivar notificaciones',
    'Turn on notifications' => 'Activar Notificaciones',
    'Unarchive' => 'Desarchivar',
    'Unlock comments' => 'Abrir los comentarios',
    'Unpin' => 'Desfijar',
    'Updated' => 'Actualizado',
    'Visible also to unregistered users' => 'También visible a usuarios no registrados',
    'Visible only to you' => 'Visible sólo para ti',
    'Visible to all Space members' => 'Visible para todos los miembros del Espacio',
    'Visible to all signed in users' => 'Visible para todos los usuarios autenticados',
    'Visible to friends of {displayName}' => 'Visible para amigos de {displayName}',
    'Visible to you and {displayName}' => 'Visible para ti y {displayName}',
    'Visible to your friends' => 'Visible para tus amigos',
    'With attachments' => 'Con archivos vinculados',
    'You cannot block the space owner!' => '¡No puedes bloquear al propietario del espacio!',
    'You cannot block the user of the same container!' => '¡No puedes bloquear al usuario del mismo contenedor!',
    'You cannot block yourself!' => '¡No puedes bloquearte a ti mismo!',
    'You do not have the permission to move this content to the given space.' => 'No tienes autorización para mover este contenido a ese espacio.',
    'You do not have the permission to move this content.' => 'No tienes autorización para mover ese contenido.',
    'Your last edit state has been saved!' => 'Este contenido ha sido grabado.',
    'in' => 'en',
    'Advanced Content Search' => '',
];
